@@ -17,10 +17,10 @@ pub enum PointerError {
 impl std::fmt::Display for PointerError {
     fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
         match *self {
-            PointerError::NulPointer => {
+            Self::NulPointer => {
                 write!(f, "dereference a null pointer will produce a crash")
             }
-            PointerError::Utf8Error(..) => {
+            Self::Utf8Error(..) => {
                 write!(f, "the provided C string is not a valid UTF-8 string")
             }
         }
@@ -30,11 +30,8 @@ impl std::fmt::Display for PointerError {
 impl std::error::Error for PointerError {
     fn source(&self) -> Option<&(dyn std::error::Error + 'static)> {
         match *self {
-            PointerError::NulPointer => None,
-            // The cause is the underlying implementation error type. Is implicitly
-            // cast to the trait object `&error::Error`. This works because the
-            // underlying type already implements the `Error` trait.
-            PointerError::Utf8Error(ref e) => Some(e),
+            Self::NulPointer => None,
+            Self::Utf8Error(ref e) => Some(e),
         }
     }
 }
